import 'package:dio/dio.dart';

class RawData {
  dynamic value;

  @override
  String toString() {
    return '{"value": $value}';
  }
}

class NetResponse<T> {
  int code;
  T? data;
  String msg = "";

  NetResponse({this.code = 0, this.data, this.msg = ""});

  @override
  String toString() {
    return 'NetResponse{code: $code, data: $data, msg: $msg}';
  }
}

class NetError {
  //code < 0 http请求错误
  //code > 0 api错误
  int code = 0;
  String? msg;

  NetError(this.code, this.msg);

  @override
  String toString() {
    return 'NetError{code: $code, msg: $msg}';
  }

  factory NetError.from(error) {
    if (error is DioError) {
      switch (error.type) {
        case DioErrorType.cancel:
          return NetError(-1, "请求取消");
        case DioErrorType.connectTimeout:
          return NetError(-1, "连接超时");
        case DioErrorType.sendTimeout:
          return NetError(-1, "请求超时");
        case DioErrorType.receiveTimeout:
          return NetError(-1, "响应超时");
        case DioErrorType.response:
          return NetError(-1, error.message);
        case DioErrorType.other:
          return NetError(-1, error.message);
      }
    } else if (error is NetError) {
      return error;
    } else {
      return NetError(-1, error.toString());
    }
  }
}
